# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["MouseDoubleClickParams"]


class MouseDoubleClickParams(TypedDict, total=False):
    x: Required[int]
    """X coordinate"""

    y: Required[int]
    """Y coordinate"""

    button: Literal["left", "middle", "right"]
    """Mouse button to use"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["FileListResponse", "Data", "DataFile"]


class DataFile(BaseModel):
    last_modified: Optional[datetime] = FieldInfo(alias="lastModified", default=None)
    """When the resource was last modified"""

    name: Optional[str] = None
    """The resource name"""

    size: Optional[int] = None
    """Resource size in bytes"""

    type: Optional[str] = None
    """Resource extension/type"""


class Data(BaseModel):
    files: Optional[List[DataFile]] = None


class FileListResponse(BaseModel):
    data: Optional[Data] = None



import json
import asyncio
import threading
from typing import Any, Dict, Callable, Optional, TypedDict
from asyncio import Future

from ..lib.browser import BrowserSetup, get_agent_ws_url


class AgentTaskParams(TypedDict, total=False):
    url: Optional[str]
    output_schema: Optional[Dict[str, Any]]
    on_agent_step: Optional[Callable[[str], None]]
    agent: Optional[str]
    highlight_elements: Optional[bool]
    model: Optional[str]
    provider: Optional[str]
    detect_elements: Optional[bool]
    extended_system_message: Optional[str]
    human_intervention: Optional[bool]
    max_steps: Optional[int]
    secret_values: Optional[Dict[str, Any]]


def create_task_payload(
    prompt: str,
    output_schema: Optional[Dict[str, Any]] = None,
    agent: Optional[str] = None,
    highlight_elements: Optional[bool] = None,
    model: Optional[str] = None,
    provider: Optional[str] = None,
    detect_elements: Optional[bool] = None,
    extended_system_message: Optional[str] = None,
    human_intervention: Optional[bool] = None,
    max_steps: Optional[int] = None,
    secret_values: Optional[Dict[str, Any]] = None,
) -> str:
    if not prompt or prompt.strip() == "":
        raise ValueError("Prompt cannot be empty")

    payload: Dict[str, Any] = {
        "prompt": prompt,
        "output_schema": output_schema,
    }
    
    if agent is not None:
        payload["agent"] = agent
    if highlight_elements is not None:
        payload["highlight_elements"] = highlight_elements
    if model is not None:
        payload["model"] = model
    if provider is not None:
        payload["provider"] = provider
    if detect_elements is not None:
        payload["detect_elements"] = detect_elements
    if extended_system_message is not None:
        payload["extended_system_message"] = extended_system_message
    if human_intervention is not None:
        payload["human_intervention"] = human_intervention
    if max_steps is not None:
        payload["max_steps"] = max_steps
    if secret_values is not None:
        payload["secret_values"] = secret_values

    return json.dumps(payload)


def on_agent_step_sync(on_agent_step: Callable[[str], None], browser_setup: BrowserSetup) -> Future[None]:
    import websockets

    async def websocket_listener() -> None:
        ws_url = get_agent_ws_url(browser_setup.base_url, browser_setup.session_id)
        try:
            async with websockets.connect(ws_url) as ws:
                async for ws_msg in ws:
                    on_agent_step(str(ws_msg))
        except Exception as e:
            future.set_exception(e)

    def run_in_thread() -> None:
        loop = asyncio.new_event_loop()
        asyncio.set_event_loop(loop)
        try:
            loop.run_until_complete(websocket_listener())
        finally:
            loop.close()

    # Create a future to track the task
    future = Future[None]()
    try:
        thread = threading.Thread(target=lambda: future.set_result(run_in_thread()))
        thread.daemon = True
        thread.start()
    except Exception:
        pass

    return future


def on_agent_step_async(on_agent_step: Callable[[str], None], browser_setup: BrowserSetup) -> None:
    import websockets

    async def websocket_listener() -> None:
        ws_url = get_agent_ws_url(browser_setup.base_url, browser_setup.session_id)
        async with websockets.connect(ws_url) as ws:
            async for ws_msg in ws:
                on_agent_step(str(ws_msg))

    asyncio.create_task(websocket_listener())



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["SessionScrollParams"]


class SessionScrollParams(TypedDict, total=False):
    delta_y: Required[Annotated[int, PropertyInfo(alias="deltaY")]]
    """Vertical scroll amount (positive is down, negative is up)"""

    x: Required[int]
    """X coordinate"""

    y: Required[int]
    """Y coordinate"""

    delta_x: Annotated[int, PropertyInfo(alias="deltaX")]
    """Horizontal scroll amount (positive is right, negative is left)"""

    steps: int
    """Number of steps to break the scroll into for smoother scrolling"""

    use_os: Annotated[bool, PropertyInfo(alias="useOs")]
    """Whether to use the OS scroll or the Playwright scroll"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["EventWaitForParams"]


class EventWaitForParams(TypedDict, total=False):
    timeout_ms: Annotated[int, PropertyInfo(alias="timeoutMs")]
    """Timeout in milliseconds to wait for the event. Defaults to 60000ms (1 minute)."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .all import (
    AllResource,
    AsyncAllResource,
    AllResourceWithRawResponse,
    AsyncAllResourceWithRawResponse,
    AllResourceWithStreamingResponse,
    AsyncAllResourceWithStreamingResponse,
)
from .agent import (
    AgentResource,
    AsyncAgentResource,
    AgentResourceWithRawResponse,
    AsyncAgentResourceWithRawResponse,
    AgentResourceWithStreamingResponse,
    AsyncAgentResourceWithStreamingResponse,
)
from .mouse import (
    MouseResource,
    AsyncMouseResource,
    MouseResourceWithRawResponse,
    AsyncMouseResourceWithRawResponse,
    MouseResourceWithStreamingResponse,
    AsyncMouseResourceWithStreamingResponse,
)
from .keyboard import (
    KeyboardResource,
    AsyncKeyboardResource,
    KeyboardResourceWithRawResponse,
    AsyncKeyboardResourceWithRawResponse,
    KeyboardResourceWithStreamingResponse,
    AsyncKeyboardResourceWithStreamingResponse,
)
from .sessions import (
    SessionsResource,
    AsyncSessionsResource,
    SessionsResourceWithRawResponse,
    AsyncSessionsResourceWithRawResponse,
    SessionsResourceWithStreamingResponse,
    AsyncSessionsResourceWithStreamingResponse,
)
from .clipboard import (
    ClipboardResource,
    AsyncClipboardResource,
    ClipboardResourceWithRawResponse,
    AsyncClipboardResourceWithRawResponse,
    ClipboardResourceWithStreamingResponse,
    AsyncClipboardResourceWithStreamingResponse,
)
from .recordings import (
    RecordingsResource,
    AsyncRecordingsResource,
    RecordingsResourceWithRawResponse,
    AsyncRecordingsResourceWithRawResponse,
    RecordingsResourceWithStreamingResponse,
    AsyncRecordingsResourceWithStreamingResponse,
)

__all__ = [
    "AllResource",
    "AsyncAllResource",
    "AllResourceWithRawResponse",
    "AsyncAllResourceWithRawResponse",
    "AllResourceWithStreamingResponse",
    "AsyncAllResourceWithStreamingResponse",
    "RecordingsResource",
    "AsyncRecordingsResource",
    "RecordingsResourceWithRawResponse",
    "AsyncRecordingsResourceWithRawResponse",
    "RecordingsResourceWithStreamingResponse",
    "AsyncRecordingsResourceWithStreamingResponse",
    "MouseResource",
    "AsyncMouseResource",
    "MouseResourceWithRawResponse",
    "AsyncMouseResourceWithRawResponse",
    "MouseResourceWithStreamingResponse",
    "AsyncMouseResourceWithStreamingResponse",
    "KeyboardResource",
    "AsyncKeyboardResource",
    "KeyboardResourceWithRawResponse",
    "AsyncKeyboardResourceWithRawResponse",
    "KeyboardResourceWithStreamingResponse",
    "AsyncKeyboardResourceWithStreamingResponse",
    "ClipboardResource",
    "AsyncClipboardResource",
    "ClipboardResourceWithRawResponse",
    "AsyncClipboardResourceWithRawResponse",
    "AgentResource",
    "AsyncAgentResource",
    "AgentResourceWithRawResponse",
    "AsyncAgentResourceWithRawResponse",
    "AgentResourceWithStreamingResponse",
    "AsyncAgentResourceWithStreamingResponse",
    "ClipboardResourceWithStreamingResponse",
    "AsyncClipboardResourceWithStreamingResponse",
    "SessionsResource",
    "AsyncSessionsResource",
    "SessionsResourceWithRawResponse",
    "AsyncSessionsResourceWithRawResponse",
    "SessionsResourceWithStreamingResponse",
    "AsyncSessionsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, Mapping
from typing_extensions import Self, override

import httpx

from . import _exceptions
from ._qs import Querystring
from ._types import (
    Omit,
    Timeout,
    NotGiven,
    Transport,
    ProxiesTypes,
    RequestOptions,
    not_given,
)
from ._utils import is_given, get_async_library
from ._version import __version__
from .resources import task, agent, tools, events, browser, profiles, extensions, identities
from ._streaming import Stream as Stream, AsyncStream as AsyncStream
from ._exceptions import APIStatusError, AnchorbrowserError
from ._base_client import (
    DEFAULT_MAX_RETRIES,
    SyncAPIClient,
    AsyncAPIClient,
)
from .resources.sessions import sessions

__all__ = [
    "Timeout",
    "Transport",
    "ProxiesTypes",
    "RequestOptions",
    "Anchorbrowser",
    "AsyncAnchorbrowser",
    "Client",
    "AsyncClient",
]


class Anchorbrowser(SyncAPIClient):
    profiles: profiles.ProfilesResource
    sessions: sessions.SessionsResource
    tools: tools.ToolsResource
    extensions: extensions.ExtensionsResource
    browser: browser.BrowserResource
    agent: agent.AgentResource
    events: events.EventsResource
    task: task.TaskResource
    identities: identities.IdentitiesResource
    with_raw_response: AnchorbrowserWithRawResponse
    with_streaming_response: AnchorbrowserWithStreamedResponse

    # client options
    api_key: str

    def __init__(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = not_given,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#client) for more details.
        http_client: httpx.Client | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new synchronous Anchorbrowser client instance.

        This automatically infers the `api_key` argument from the `ANCHORBROWSER_API_KEY` environment variable if it is not provided.
        """
        if api_key is None:
            api_key = os.environ.get("ANCHORBROWSER_API_KEY")
        if api_key is None:
            raise AnchorbrowserError(
                "The api_key client option must be set either by passing api_key to the client or by setting the ANCHORBROWSER_API_KEY environment variable"
            )
        self.api_key = api_key

        if base_url is None:
            base_url = os.environ.get("ANCHORBROWSER_BASE_URL")
        if base_url is None:
            base_url = f"https://api.anchorbrowser.io"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

        self.profiles = profiles.ProfilesResource(self)
        self.sessions = sessions.SessionsResource(self)
        self.tools = tools.ToolsResource(self)
        self.extensions = extensions.ExtensionsResource(self)
        self.browser = browser.BrowserResource(self)
        self.agent = agent.AgentResource(self)
        self.events = events.EventsResource(self)
        self.task = task.TaskResource(self)
        self.identities = identities.IdentitiesResource(self)
        self.with_raw_response = AnchorbrowserWithRawResponse(self)
        self.with_streaming_response = AnchorbrowserWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @property
    @override
    def auth_headers(self) -> dict[str, str]:
        api_key = self.api_key
        return {"anchor-api-key": api_key}

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": "false",
            **self._custom_headers,
        }

    def copy(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = not_given,
        http_client: httpx.Client | None = None,
        max_retries: int | NotGiven = not_given,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(
            api_key=api_key or self.api_key,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class AsyncAnchorbrowser(AsyncAPIClient):
    profiles: profiles.AsyncProfilesResource
    sessions: sessions.AsyncSessionsResource
    tools: tools.AsyncToolsResource
    extensions: extensions.AsyncExtensionsResource
    browser: browser.AsyncBrowserResource
    agent: agent.AsyncAgentResource
    events: events.AsyncEventsResource
    task: task.AsyncTaskResource
    identities: identities.AsyncIdentitiesResource
    with_raw_response: AsyncAnchorbrowserWithRawResponse
    with_streaming_response: AsyncAnchorbrowserWithStreamedResponse

    # client options
    api_key: str

    def __init__(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = not_given,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultAsyncHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#asyncclient) for more details.
        http_client: httpx.AsyncClient | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new async AsyncAnchorbrowser client instance.

        This automatically infers the `api_key` argument from the `ANCHORBROWSER_API_KEY` environment variable if it is not provided.
        """
        if api_key is None:
            api_key = os.environ.get("ANCHORBROWSER_API_KEY")
        if api_key is None:
            raise AnchorbrowserError(
                "The api_key client option must be set either by passing api_key to the client or by setting the ANCHORBROWSER_API_KEY environment variable"
            )
        self.api_key = api_key

        if base_url is None:
            base_url = os.environ.get("ANCHORBROWSER_BASE_URL")
        if base_url is None:
            base_url = f"https://api.anchorbrowser.io"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

        self.profiles = profiles.AsyncProfilesResource(self)
        self.sessions = sessions.AsyncSessionsResource(self)
        self.tools = tools.AsyncToolsResource(self)
        self.extensions = extensions.AsyncExtensionsResource(self)
        self.browser = browser.AsyncBrowserResource(self)
        self.agent = agent.AsyncAgentResource(self)
        self.events = events.AsyncEventsResource(self)
        self.task = task.AsyncTaskResource(self)
        self.identities = identities.AsyncIdentitiesResource(self)
        self.with_raw_response = AsyncAnchorbrowserWithRawResponse(self)
        self.with_streaming_response = AsyncAnchorbrowserWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @property
    @override
    def auth_headers(self) -> dict[str, str]:
        api_key = self.api_key
        return {"anchor-api-key": api_key}

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": f"async:{get_async_library()}",
            **self._custom_headers,
        }

    def copy(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = not_given,
        http_client: httpx.AsyncClient | None = None,
        max_retries: int | NotGiven = not_given,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(
            api_key=api_key or self.api_key,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class AnchorbrowserWithRawResponse:
    def __init__(self, client: Anchorbrowser) -> None:
        self.profiles = profiles.ProfilesResourceWithRawResponse(client.profiles)
        self.sessions = sessions.SessionsResourceWithRawResponse(client.sessions)
        self.tools = tools.ToolsResourceWithRawResponse(client.tools)
        self.extensions = extensions.ExtensionsResourceWithRawResponse(client.extensions)
        self.browser = browser.BrowserResourceWithRawResponse(client.browser)
        self.agent = agent.AgentResourceWithRawResponse(client.agent)
        self.events = events.EventsResourceWithRawResponse(client.events)
        self.task = task.TaskResourceWithRawResponse(client.task)
        self.identities = identities.IdentitiesResourceWithRawResponse(client.identities)


class AsyncAnchorbrowserWithRawResponse:
    def __init__(self, client: AsyncAnchorbrowser) -> None:
        self.profiles = profiles.AsyncProfilesResourceWithRawResponse(client.profiles)
        self.sessions = sessions.AsyncSessionsResourceWithRawResponse(client.sessions)
        self.tools = tools.AsyncToolsResourceWithRawResponse(client.tools)
        self.extensions = extensions.AsyncExtensionsResourceWithRawResponse(client.extensions)
        self.browser = browser.AsyncBrowserResourceWithRawResponse(client.browser)
        self.agent = agent.AsyncAgentResourceWithRawResponse(client.agent)
        self.events = events.AsyncEventsResourceWithRawResponse(client.events)
        self.task = task.AsyncTaskResourceWithRawResponse(client.task)
        self.identities = identities.AsyncIdentitiesResourceWithRawResponse(client.identities)


class AnchorbrowserWithStreamedResponse:
    def __init__(self, client: Anchorbrowser) -> None:
        self.profiles = profiles.ProfilesResourceWithStreamingResponse(client.profiles)
        self.sessions = sessions.SessionsResourceWithStreamingResponse(client.sessions)
        self.tools = tools.ToolsResourceWithStreamingResponse(client.tools)
        self.extensions = extensions.ExtensionsResourceWithStreamingResponse(client.extensions)
        self.browser = browser.BrowserResourceWithStreamingResponse(client.browser)
        self.agent = agent.AgentResourceWithStreamingResponse(client.agent)
        self.events = events.EventsResourceWithStreamingResponse(client.events)
        self.task = task.TaskResourceWithStreamingResponse(client.task)
        self.identities = identities.IdentitiesResourceWithStreamingResponse(client.identities)


class AsyncAnchorbrowserWithStreamedResponse:
    def __init__(self, client: AsyncAnchorbrowser) -> None:
        self.profiles = profiles.AsyncProfilesResourceWithStreamingResponse(client.profiles)
        self.sessions = sessions.AsyncSessionsResourceWithStreamingResponse(client.sessions)
        self.tools = tools.AsyncToolsResourceWithStreamingResponse(client.tools)
        self.extensions = extensions.AsyncExtensionsResourceWithStreamingResponse(client.extensions)
        self.browser = browser.AsyncBrowserResourceWithStreamingResponse(client.browser)
        self.agent = agent.AsyncAgentResourceWithStreamingResponse(client.agent)
        self.events = events.AsyncEventsResourceWithStreamingResponse(client.events)
        self.task = task.AsyncTaskResourceWithStreamingResponse(client.task)
        self.identities = identities.AsyncIdentitiesResourceWithStreamingResponse(client.identities)


Client = Anchorbrowser

AsyncClient = AsyncAnchorbrowser
